\name{FormatGenotypes}
\alias{FormatGenotypes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Formatting file of genotype data.}
\description{Takes genotype data as a matrix with
  one line per individual and two columns per locus,
  with alleles coded by integers (number of replications for
  micro-satellites data).
  Build a new matrix with alleles acodes as consecutive integer.
  If allele j has 7 alleles they will be coded as 1,2,...7.
}
\usage{
FormatGenotypes(genotypes)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{genotypes}{A matrix with
  one line per individual and two columns per locus,
  with alleles coded by integers}
}

\value{
  A matrix with
  one line per individual and two columns per locus,
  with alleles coded by integers}


\author{Gilles Guillot}


\keyword{}
\eof
\name{Fstat}
\alias{Fstat}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{F statistics}
\description{Computes F statistics according to Weir and Cockerham's 
  estimators.}

\usage{
Fstat(repdat, repmcmc)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
   \item{repdat}{ Path to input files directory }
  \item{repmcmc}{ Path to output files directory }
}
}
\value{A list with components 
  \item{Total.Fit }{A real number estimating the total Fit}
  \item{Pairwise.Fis }{A matrix of real numbers estimating the pairwise Fis}
  \item{Pairwise.Fst }{A matrix of real numbers estimating the pairwise Fst}
  \item{Pairwise.Fit }{A matrix of real numbers estimating the pairwise Fit}
}

\author{Arnaud Estoup for original code in Turbo Pascal.

  Translation in Fortran and interface with R by Gilles Guillot}

\references{ Weir, B.S. and C.C. Cockerham, 
  Estimating F-statistics for the analysis of population structure,
  Evolution, 1984,
  vol. 38, 1358-1370.
}

\keyword{}
\eof
\name{Geneland}
\alias{Geneland}
\title{Simulation and inference of a 
  spatial statistical model for landscape genetics.}

\description{
  The main function \code{\link{mcmcFmodel}} 
  takes geo-referenced individual multilocus genetic data and tries to detect
  population structure, i.e sub-populations making use of both spatial and genetic information.
}

\details{
The overall population is viewed as a co-existence of sub-populations at 
  Hardy-Weiberg equilibrium. The sub-populations are supposed to be spatially 
  organised through the so-called 
  colored Poisson-Voronoi tessellation. 
  Allele frequencies are assumed to be drawn from the F-model 
  as described in (Falush 2003) although 
  the particular case of independent Dirichlet allele frequencies, 
  as described by Pritchard (2000),  is also handled. 
  Individuals within populations are assumed to be randomly 
  located and  Hardy-Weiberg equilibrium 
  and linkage equilibrium are assumed.
  
  The main purpose of the program is to perform Bayesian inference of all the parameters involved 
  through Markov Chain Monte-Carlo simulation.
  This is achievied by the function   \code{\link{mcmcFmodel}}.
  Function \code{\link{PostProcessChain}} read some output files of
  \code{\link{mcmcFmodel}}
  and computes some statistics suitable to print maps of inferred
  populations.
  
  See \code{Storage format} section in \code{\link{mcmcFmodel} help page.}

  The following functions are provided by the package:

  
  \code{\link{simFmodel}}: simulation from the prior of the spatial
  F-model
  
  \code{\link{mcmcFmodel}}: Full Bayesian Markov Chain Monte Carlo
  inference of parameters in the spatial F-model
  
  \code{\link{PostProcessChain}}: Post-procesing of MCMC output
  for maps of posterior probability of populations subdomains
    
  \code{\link{PlotTessellation}}: Graphical display of inferred
  sub-domains

  The following  functions are very basic and are only intended to be an
  aid for those not familiar with R. Most probably you may want to use
  directly the output files of \code{\link{mcmcFmodel}} and
  \code{\link{PostProcessChain}} to print your own figures.
  
  \code{\link{PlotDrift}}: Graphical display of drift factors along MCMC
  run
  
   \code{\link{PlotFreqA}}: Graphical display of allele frequencies in the
   ancestral population along MCMC run
   
   \code{\link{PlotFreq}}: Graphical display of allele frequencies in the
   present time population along MCMC run
   
   \code{\link{Plotnclass}}: Graphical display of number of populations
   along MCMC run
   
   \code{\link{Plotntile}}: Graphical display of number of tiles along
   MCMC run
   
   \code{\link{PosteriorMode}}: Computation and/or graphical display of
   mode in the posterior distribution of class membership at each pixel
   
   \code{\link{Fstat}}: Computations of pairwise F statistics between
   inferred subpopulations 

   \code{\link{FormatGenotypes}}: Transform a file of genotypes into
   a format suitable for function \code{\link{mcmcFmodel}}

   \code{\link{setplot}}: Internal function

   \code{\link{rdiscr}}: Internal function
}


\references{

  On the implementation of mixture models in population genetics:
  
- J.K. Pritchard, M. Stephens and P. Donnelly,
Inference of population structure using multilocus genotype data,
Genetics, pp 945-959 vol. 155, 2000

- Falush D., M. Stephens and  J.K. Pritchard, 
Inference of population structure using multilocus genotype data:
Linked loci and correlated allele frequencies, Genetics, pp 1567-1587,
vol 164, 2003

On the implementation of variable dimension MCMC algorihtm in
population genetics:

- Corander, J.C., Waldmann, P. and Sillanpaa, M.J.,
Bayesian analysis of genetic differentiation between populations,
Genetics, 2003, 163, 367-374

- Corander, J.C.,  P. Waldmann, P. Martinen and  M.J. Sillanpaa, ,
BAPS2: Enhanced possibilities for the analysis of genetic population structure,
Bioinformatics, vol. 20,number 15, 2004

On the use of Voronoi tessellations in population genetics :

- Dupanloup, I., Schneider, S. and Excoffier, L.,
A simulated annealing approach to define genetic structure of populations,
Molecular Ecology, 2002, 11, 2571-2581

On the model (and sub-models) implemented in \code{Geneland}

- Guillot G. A. Estoup, F. Mortier, J.F. Cosson, A spatial statistical model for
landscape genetics, Genetics, 2005

- Guillot, G., Geneland : A program for landscape genetics.
Molecular Ecology   Notes, submited.




}

\author{Gilles Guillot

\url{http://www.inapg.inra.fr/ens_rech/mathinfo/personnel/guillot/welcome.html}

}


\keyword{}
\eof
\name{PlotDrift}
\alias{PlotDrift}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Plot the drift factors}
\description{Gives a plot of the trace of the drift factors along the
  MCMC run}
\usage{
PlotDrift(repmcmc,printit=FALSE,file=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repmcmc}{ Path to output files directory }
   \item{printit}{Logical : if TRUE, figures are also printed}
  \item{file}{Character : Path to file where figures
    should be printed}
}

\references{A spatial statistical model for landscape genetics, Guillot,
  Estoup, Mortier, Cosson, Genetics, 2005

 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.
}
\author{Gilles Guillot  }


\keyword{}
\eof
\name{PlotFreq}
\alias{PlotFreq}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Plot the trace of allele frequencies in present time population
  and optionnaly print it.}

\description{Plot of allele frequencies in present time populations number
  \code{ipop},
  for allele \code{iall}  of locus \code{iloc}}

\usage{
PlotFreq(repdat, repmcmc,ipop,iloc,iall,printit=FALSE,path=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
   \item{repdat}{ Path to input files directory }
   \item{repmcmc}{ Path to output files directory }
   \item{ipop} {Integer number : index of population}
   \item{iloc}{Integer number : index of locus}
   \item{iall}{Integer number : index of allele}
   \item{printit}{Logical : if TRUE, figures are also printed}
   \item{path}{Character : Path to directory where figures
     should be printed}
  }




\references{A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005}
\author{Gilles Guillot  }

\keyword{}





\eof
\name{PlotFreqA}
\alias{PlotFreqA}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Plots allele frequencies in ancestral population along the MCMC run
  and optionally prints it}

\description{Plot frequency of  allele \code{iall}  of locus \code{iloc}
  in ancestral population}

\usage{
PlotFreqA(repdat, repmcmc,iloc,iall,printit=FALSE,path=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
   \item{repdat}{ Path to input files directory }
   \item{repmcmc}{ Path to output files directory }
   \item{iloc}{Integer number : index of locus}
   \item{iall}{Integer number : index of allele}
   \item{printit}{Logical : if TRUE, figures are also printed}
   \item{path}{Character : Path to directory where figures
    should be printed}
 }


\references{A spatial statistical model for landscape genetics, Guillot,
  Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }



\keyword{}
\eof
\name{PlotTessellation}
\alias{PlotTessellation}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Maps of posterior probability  of membership}
\description{Plots maps of posterior probabilities  of population
  membership for each population}
\usage{
PlotTessellation(repdat, repmcmc,printit,path)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repdat}{Character : Path to input files directory }
  \item{repmcmc}{Character : Path to output files directory }
  \item{printit}{Logical : if TRUE, figures are also printed}
  \item{path}{Character : Path to directory where figures
      should be printed}
}

\references{A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }


\seealso{ \code{\link{PostProcessChain}}}


\keyword{}

\eof
\name{Plotnclass}
\alias{Plotnclass}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Plot of number of populations along the MCMC run}
\description{Gives a plot of the number of populations along the MCMC run
}
\usage{
Plotnclass(repmcmc,printit=FALSE,file=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repmcmc}{ Path to output files directory }
  \item{printit}{Logical : if TRUE, figures are also printed}
  \item{file}{Character : Path to file where figures
    should be printed}
}

\references{A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }

\keyword{}

\eof
\name{Plotntile}
\alias{Plotntile}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Plot of number of tiles along the MCMC run}
\description{Plot of number of tiles in the Poisson-Voronoi tessellation
  along the MCMC run}

\usage{
Plotntile(repmcmc,printit=FALSE,file=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repmcmc}{ Path to output files directory }
   \item{printit}{Logical : if TRUE, figures are also printed}
  \item{file}{Character : Path to file where figures
    should be printed}
}
\references{A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }


\keyword{}
\eof
\name{PostProcessChain}
\alias{PostProcessChain}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Computation for  maps of posterior probability of population membership}
\description{
 Computes posterior probabilities of population membership for each pixel
 of the spatial domain. 
}
\usage{
PostProcessChain(repdat, repmcmc,nxdom, nydom,burnin)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repdat}{ Path to input files directory }
  \item{repmcmc}{ Path to output files directory }
  \item{nxdom}{Number of pixel for discretization of the spatial domain
    in the horizontal direction}
  \item{nydom}{Number of pixel for discretization of the spatial domain
    in the vertical direction}
  \item{burnin}{Number of iterations of the chain to throwaway}
}
\details{ \code{repdat} directory should contain at least three files
  named   exactly :
  \code{coordinates.txt}, \code{genotypes.txt} and
  \code{allele.numbers.txt} and containing respectively the spatial
  coordinates, the genotypes and the number of alleles per locus.

    See format of files simulated by \code{\link{simFmodel}} for an
  example. 
  
}
\value{
  Posterior probability of population membership for each pixel are
  written in an ascii file called \code{proba.pop.membership.txt}
  (one column per population,
  \code{nclassmax} values are computed for each pixel, 
  pixels are stored  row-wise starting from bottom left).

  Another file called \code{proba.pop.membership.perm.txt} tries
  to get rid of label switching
  issues by labelling the population according to a fixed constraint.
  (This has has proved to be usefull with a small number of loci, (e.g. nloc=3), for well
  differentiated populations.)
}
\references{A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }




\seealso{\code{\link{PlotTessellation}}}


\keyword{}

\eof
\name{PosteriorMode}
\alias{PosteriorMode}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Map of mode of posterior distribution of population membership}
\description{Plots a map giving  the modal population as a
  color code for each pixel.}

\usage{
PosteriorMode(repdat, repmcmc,write = FALSE,
plotit = TRUE,printit=FALSE,file=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repdat}{ Path to input files directory }
  \item{repmcmc}{ Path to output files directory }
  \item{write}{Logical: if TRUE the modal class of each individual is
    written in a plain ascci file named pm.txt}
  \item{plotit}{Logical: if TRUE the map is plotted}
  \item{printit}{Logical : if TRUE, figures are also printed}
  \item{file}{Character : Path to file where figures
    should be printed}
}

\references{A spatial statistical model for landscape genetics, Guillot,
  Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.

}
\author{Gilles Guillot  }

\keyword{}

\eof
\name{mcmcFmodel}
\alias{mcmcFmodel}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Inference in a  spatial statistical model  }
\description{ Markov Chain Monte-Carlo inference in the spatial F-model}
\usage{
mcmcFmodel(repdat, repmcmc, lambdamax, dt, nclassmin, nclassinit,
nclassmax, nppmax, nchain, stepw, model, varnclass, spatial)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{repdat}{ Path to input files directory }
  \item{repmcmc}{ Path to output files directory }
  \item{lambdamax}{Maximum rate of Poisson process  (real number >0).
  Setting \code{lambdamax} equal to the number of individuals in the
  dataset has proved to be efficient in many cases.}
  \item{dt}{ Parameter prescribing the amount of unctertainty attached
    to spatial coordinates. If \code{dt}=0 spatial coordinates are
    consiered as true coordinates, if \code{dt}>0 it is assumed that observed
  coordinates are true coordinates blurred by an additive noise uniform
  on a square of side \code{dt} centered on 0.}
  \item{nclassmin}{Minimum number of populations (integer >=1) }
  \item{nclassinit}{Initial number of populations
    ( integer sucht that
    \code{nclassmin} =< \code{nclassinit} =< \code{nclassmax})}
  \item{nclassmax}{Maximum number of populations (integer >=
    \code{nclassinit}).
    There is no obvious rule to select \code{nclassmax},
    it should be set to a value larger than any value that
    you can reasonably expect for your data.}
  \item{nppmax}{Integer: Maximum number of nuclei in the
    Poisson-Voronoi tessellation. A good guess consists in setting this
    value equal to \code{10*lambdamax}. The relevance of this rule can be
    checked by inspection of the MCMC run. The number of tiles should not
    go too close from \code{nppmax}. If it does, you should re-run your
    chain  with a larger value for \code{nppmax}}.
  \item{nchain}{Number of MCMC iterations}
  \item{stepw}{Number of MCMC iterations between two writing steps (if \code{stepw}=1, all
    states are saved whereas if e.g. \code{stepw}=10 only each 10 iteration is saved)}
  \item{model}{Character: "Falush" or "Dirichlet" (model for
    frequencies). 
  See also details in detail section of \code{\link{Geneland}} help page.}
  \item{varnclass}{Logical: if TRUE the number of class is treated as
    unknown and will vary along the MCMC inference, if FALSE it will be
    fixed to the initial value \code{nclassinit}. 
    \code{varnclass = TRUE} *should not* be used in conjunction with
    \code{model = "Falush"} as in this case it seems that large numbers
    of populations are not penalized enough and there is a serious risk
    of inferring spurious sub-populations.}
    
  \item{spatial}{Logical: if TRUE the colored Poisson-Voronoi
    tessellation is used as a prior for the spatial organisation of
    populations. If FALSE, all clustering receive equal prior
    probability. In this case spatial information (i.e coordinates)
    are not used  and the locations of  the nuclei are initialized and
    kept fixed at the locations of individuals.}
   
}
\details{ \code{repdat} directory should contain at least three files
  named exactly :   \code{ coord.txt},  \code{genotypes.txt} and
  \code{allele.numbers.txt}   and containing respectively the spatial
  coordinates, the genotypes and the number of alleles per locus.
  
  These files should be plain ascci files with no header.
  \code{coordinates.txt} should have one line per individual
  and two columns (x, y coordinates) missing value are not allowed.
  
  \code{genotypes.txt}  should have one line per individual
  and two columns per locus,
  alleles should be coded as integer between 1 and the maximum number of
  alleles for this locus, missing genotypic values should be coded as -999.
  If your initial file as the required number of lines and columns but
  with alleles coded with non-consecutive integers, then the function
  \code{\link{FormatGenotypes}} should be used first. 
  
  \code{allele.numbers.txt} should have one line per locus an one column
  giving number of alleles for consecutive loci.

  
}


\value{
Successive states of all blocks of parameters are written in files
contained in \code{repout} and named after the type of parameters they contain.
}
\section{Storage format}{
All parameters processed by function \code{\link{mcmcFmodel}} are
written in the directory  specified by \code{repout} as follows:

\item File \code{population.numbers.txt} contains values of the number of
populations (\code{nchain} lines, one line per iteration of the MCMC algorithm)

\item File \code{nuclei.numbers.txt} contains the number of points in the Poisson
point process generating the Voronoi tessellation

\item File \code{color.nuclei.txt} contains vectors of integers of
length \code{nppmax} coding the class membership of each Voronoi tile.
Vectors of class membership for successive states of the chain are
concatenated in one column. Some entries of the vector containing
clas membership for a current state may have missing values as the
actual number of polygon may be smaller that the maximum number allowed
\code{nppmax}. 
This file has \code{nppmax*chain/stepw} lines

\item File \code{coord.nuclei.txt} contains coordinates of points in the Poisson
point process generating the Voronoi tessellation. It has
\code{nppmax*chain/stepw} lines
and two columns (hor. and vert. coordinates).

\item File \code{drifts.txt} contains the drift factors for each
population, (one column per population). 

\item File \code{ancestral.frequencies.txt} contains allele frequencies in ancestral
population. Each line contains all frequencies of the current state.
The file has \code{nchain} lines.
In each line, values of allele frequencies are stored by increasing
allele index and and locus index (allele index varying first).

\item File \code{frequencies.txt} contains allele frequencies of present time
populations. Column xx contains frequencies of population numer xx.
In each column values of allele frequencies are stored by increasing
allele index and and locus index (allele index varying first), and
values of successive iterations are pasted.
The file has \code{nallmax*nloc*nchain/stepw} lines where \code{nallmax} 
is the maximum numer of alleles over all loci.

\item File \code{Poisson.process.rate.txt} contains rates of Poisson process

\item File \code{log.likelihood.txt} contains log-likelihood of data
for the current state of parameters of the Markov chain.

\item File \code{log.posterior.density.txt} contains log of posterior probability
(up to marginal density of data) of the
current state of parameters in the Markov chain.


}

\references{A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }



\seealso{ \code{\link{simFmodel}}}

\examples{
  # Below is a complete sequence 
  # of commands using Geneland functions

  # we assume that Geneland is installed
  # and loaded by library("Geneland")



  #  first look for a place to write
  #  simulated data and MCMC outputs
if(.Platform$OS == "unix"){
repdat = "/tmp/"
repmcmc= "/tmp/"
}

if(.Platform$OS == "windows"){
repdat = "/temp/"
repmcmc= "/temp/"
}

 # Simulation of a dataset made of 2 populations
 # 2 loci and 2 alleles per locus
simFmodel(nindiv=100,
          slim=c(0,1,0,1),
          npp=2,
          nloc=5,
          nall=c(5,5,5,5,5),
          nclass=2,
          drift=c(.3,.3),
          plots=FALSE,
          ploth=FALSE,
          seed=12345,
          write=TRUE,
          repout=repdat)


  # First run of MCMC algorithm
  # in order to get the posterior mode of the number of populations
mcmcFmodel(repdat=repdat,
           repmcmc=repmcmc,
           lambdamax=100,
           dt=0,
           nclassmin=1,
           nclassinit=5,
           nclassmax=10,
           nppmax=200,
           nchain=5000,
           stepw=10,
           model="Dirichlet",
           varnclass=TRUE,
           spatial=TRUE)

 # Trace of number of populations
 # Should display a mode at 2
Plotnclass(repdat,repmcmc)


 # Then re-run the chain with fixed number of populations
mcmcFmodel(repdat=repdat,
           repmcmc=repmcmc,
           lambdamax=100,
           dt=0,
           nclassmin=1,
           nclassinit=2,
           nclassmax=2,
           nppmax=200,
           nchain=5000,
           stepw=10,
           model="Dirichlet",
           varnclass=FALSE,
           spatial=TRUE)

  # Post-processing the chain 
PostProcessChain(repdat=repdat,
                 repmcmc=repmcmc,
                 nxdom=50,
                 nydom=50,
                 burnin=0)

  # Plots allele frequencies of allele #1 at locus  #1 in sub-population  #1
PlotFreq(repdat=repdat,repmcmc=repmcmc,ipop=1,iloc=1,iall=1)

  # Map of posterior probabilites
  # of population membership
PlotTessellation(repdat=repdat,repmcmc=repmcmc)


  # Map of posterior mode 
  # of population membership
PosteriorMode(repdat=repdat,repmcmc=repmcmc,
              write=FALSE,plotit=TRUE)




}

\keyword{}

\eof
\name{rdiscr}
\alias{rdiscr}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Internal function for the simulation of a categorical random variable}
\description{Simulation one value from categorical distribution}
\usage{
rdiscr(f)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{f}{Vector of frequencies (sum(\code{f}) should be equal to one}
}
\details{

}
\value{
 An integer drawn from the categorical distribution
}


\keyword{}
\eof
\name{setplot}
\alias{setplot}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Set graphical parameters for  geographical maps so as to have equal ratio for horizontal
and vertical axis. Internal function.}
\description{Set graphical parameters so as to have equal ratio for horizontal
and vertical axis.}
\usage{
setplot(xdata, ydata, pretty.call = TRUE, maxdim, axes = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{xdata}{A vector of x coordinates}
  \item{ydata}{A vector of y coordinates}
  \item{pretty.call}{ ~~Describe \code{pretty.call} here~~ }
  \item{maxdim}{ ~~Describe \code{maxdim} here~~ }
  \item{axes}{ ~~Describe \code{axes} here~~ }
}
}
\value{Reset graphical parameters}

\author{?}

\keyword{}


\eof
\name{simFmodel}
\alias{simFmodel}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Simulation of multi-locus genetic data from the spatial F-model}
\description{
  Simulates multi-locus genotypes and spatial coordinates for 
  individuals belonging to some spatially organised populations.
}
\usage{
simFmodel(nindiv, s = NULL, slim, npp, u = NULL, c = NULL,
nloc, nall, nclass, drift, seed=NULL, plots = TRUE, ploth = TRUE, write = FALSE, repout=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{nindiv}{Integer:  Number of individuals}
  \item{s}{ Matrix (2 rows, \code{nindiv} columns) of spatial
    coordinates of individuals}
  \item{slim}{ Vector of limits of spatial domain to be considered (abs
    min, abs max, ord min, ord max) }
  \item{npp}{ Integer: number of nuclei in the Voronoi tessellation}
  \item{u}{Coordinates of nuclei of Voronoi tessellation}
  \item{c}{Population labels of the nuclei (vector of integers of size \code{npp})}
  \item{nloc}{ number of loci}
  \item{nall}{ Vector of integers (of size \code{nloc}) giving number of alleles at each locus}
  \item{nclass}{Number of populations }
  \item{drift}{Vector (of size \code{nclass}) of drift factors between 0
  and 1}
  \item{seed}{Seed to initialize the random number generator}
  \item{plots}{Logical: if TRUE, spatial coordinates are ploted}
  \item{ploth}{Logical: if TRUE, barplots for allele frequencies are ploted}
  \item{write}{Logical: if TRUE, data are written to directory \code{repout}}
  \item{repout}{Path to output directory}
}
\details{ \code{npp} uniform i.i.d points are randomly spread on
  the rectangular domain. These points generates the so called Voronoi
  tessellation of the domain in \code{npp} polygonal sub-domains. Each
  polygon is given a color uniformly on {1, \code{nclass}}. The union
  of polygons of the color k gives the domain of population k.
Then \code{nindiv} uniform i.i.d  points are randomly spread on the
domain and stand for the locations of individuals.
Allele frequencies in the ancestral population are sampled from
independent Dirichlet D(1,...,1).
Allele frequencies in the present time population are drawn from
Dirichlet distrubution whose parameters depend on drift factors
\code{drift} and allele frequencies in the ancestral population.
Individual genotypes in each population are drawn from the allele
frequencies of the corresponding population assuming Hardy-Weinberg
equilibrium and linkage equilibrium. }

\value{Simulated values are written in files in \code{repout} directory}

\references{Falush D., M. Stephens, J.K. Pritchard, 
  Inference of population structure using multilocus genotype data:
  Linked loci and correlated allele frequencies, Genetics, pp 1567-1587,
  vol 164, 2003

  A spatial statistical model for landscape genetics, Guillot,
Estoup, Mortier, Cosson, Genetics, 2005
  
 Guillot, G., Geneland : A program for landscape genetics.
 Molecular Ecology  Notes, submited.}
\author{Gilles Guillot  }




\seealso{ Function \code{\link{mcmcFmodel}} for inference}

\keyword{}
\eof
